<?php
declare (strict_types = 1);

namespace app\admin\controller;

use app\BaseController;
use think\App;
use think\facade\Db;
use think\Request;

class Menu extends BaseController
{

    private $uid = '';
    /**
     * 显示资源列表
     *
     * @return \think\Response
     */
    public  function __construct(App $app)
    {
        parent::__construct($app);
        $post  =$this->request->post();
        $token = isset($post['token']) ? trim($post['token']) : "";
        if($token==""){
            return error_show(101,'token不能为空');

        }
        $effetc = VerifyTokens($token);
        if(!empty($effetc) && $effetc['code']!=0){
            return error_show($effetc['code'],$effetc['message']);
        }
        $this->uid = isset($effetc['data']['user']['id']) ? $effetc['data']['user']['id'] :"";
    }

    public function list()
    {
        $post=$this->request->post();
        $uid = $this->uid;
        if($uid==''){
            return error_show(101,'未找到用户信息');
        }
        $roleid = Db::name("user_role")->where([["uid","=",$uid],["status","=",1],["is_del","=",0]])->find();
        if(empty($roleid)){
            return error_show(1004,'未找到用户权限信息');
        }
        $role = Db::name("role_action")->where("role_id","=", $roleid['roleid'])->find();
        if($role==false){
            return app_show(0,"获取成功",[]);
        }
        $data= Db::name("view_menu")->where('aid',"in",explode(",",$role['action_conllect']))->where(['status'=>1,"cstatus"=>1,"is_display"=>1])
            ->order("weight desc,id asc,cweight desc,cid asc")->select();

        $list=[];
        $act=[];
        foreach ($data as $value){
            $list[$value["id"]]['menu_name']=$value['menu_name'];
            $list[$value["id"]]['menu_img']=$value['menu_img'];
            $list[$value["id"]]['menu_route']=$value['menu_route'];
            $list[$value["id"]]['is_display']=$value['is_display'];
            $list[$value["id"]]['status']=$value['status'];
            $temp = [];
            $temp['menu_name']=$value['cname'];
            $temp['menu_img']=$value['cmenu_img'];
            $temp['menu_route']=$value['cmenu_route'];
            $temp['menu_url']=$value['cmenu_url'];
            $temp['menu_url']=$value['cmenu_url'];
            $temp['status']=$value['cstatus'];
            $temp['is_private']=$value['cprivate'];
            $temp['is_display']=$value['cis_display'];
            $list[$value["id"]]['child'][$value['cid']]=$temp;
            $act[$value['id']][$value['cid']][]=$value['acode'];
            $list[$value["id"]]['child'][$value['cid']]['action']= $act[$value['id']][$value['cid']];

        }
        array_walk($list,function (&$value){
            $value['child']= array_values($value['child']);
        });
        return app_show(0,"获取成功",array_values($list));
    }

    /**
     * 显示创建资源表单页.
     *
     * @return \think\Response
     */
    public function MenuEdit(){
        $post  =$this->request->post();
        $id = isset($post['id']) ?intval($post['id']) :"";
        if($id!=""){
            $menu = Db::name("admin_menu")->where("id","=",$id)->find();
            if($menu==false){
                return error_show(1003,"菜单不信息不存在");
            }
        }
        $name = isset($post['name']) ?trim($post['name']) :"";
        if($name==""){
            return error_show(1002,"菜单名称不能为空");
        }
        $url = isset($post['url']) ?trim($post['url']) :"";
        $route = isset($post['route']) ?trim($post['route']) :"";
        $code = isset($post['menu_code']) ?trim($post['menu_code']) :"";
        $img = isset($post['img']) ?trim($post['img']) :"";
        $pid = isset($post['pid']) ?intval($post['pid']) :0;
        $weight = isset($post['weight']) ?floatval($post['weight']) :1;
        $status = isset($post['is_show']) ? intval($post['is_show']) : 0;
        $is_display = isset($post['is_display']) ? intval($post['is_display']) : 0;
        $private = isset($post['private']) ?intval($post['private']) :(isset($menu['is_private']) ?
            $menu['is_private'] : 0);
        if($pid!=0 && $route==""){
            return error_show(1002,"子级菜单路由不能为空");
        }
        $data=[
            "menu_name"=>$name,
            "menu_url"=>$url,
            "menu_route"=>$route,
            "menu_code"=>$code,
            "menu_img"=>$img,
            "pid"=>$pid,
            'is_show'=>$status,
            'is_display'=>$is_display,
            "is_private"=>$private,
            'status'=>1,
            "weight"=>$weight,
            "updatetime"=>date("Y-m-d H:i:s"),
        ];
        $message="新建";
        if($id!=""){
            $message="编辑";
            $data['id']=$id;
        }
        $result = Db::name("admin_menu")->save($data);
        return $result ? app_show(0,"{$message}成功"): error_show(1003,"{$message}失败");
    }

    /**
     * 保存新建的资源
     *
     * @param  \think\Request  $request
     * @return \think\Response
     */
    public function MenuStatus(){
        $post  =$this->request->post();

        $id = isset($post['id']) ?intval($post['id']) :"";
        $menu = Db::name("admin_menu")->where("id","=",$id)->find();
        if($menu==false){
            return error_show(1003,"菜单信息不存在");
        }
        $statu = isset($post['status'])&&$post['status']!="" ? intval($post['status']) :"";
        if($statu===""){
            return error_show(1003,"菜单状态不能为空");
        }
        $menu['status']=$statu;
        $menu['updatetime']=date("Y-m-d H:i:s");
        $result = Db::name("admin_menu")->save($menu);
        return $result ? app_show(0,"状态更新成功"): error_show(1003,"状态更新失败");
    }

    /**
     * @return \think\response\Json|void
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     * @throws \think\exception\DbException
     */
    public function   MenuAllList(){
        $post  =$this->request->post();

        $data = Db::name("admin_menu")->where(['pid'=>0,'is_del'=>0])->order("weight desc,id asc")->select();
        $l=[];
        foreach ($data as $key=>$value){
            $temp=[];
            $temp =  Db::name("admin_menu")->where(['pid'=>$value['id'],'is_del'=>0])->order("weight desc,id asc")
                ->select();
            $value['child']=$temp;
            $l[]=$value;
        }
        return app_show(0,"获取成功",$l);
    }

    /**
     * @return \think\response\Json|void
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     * @throws \think\exception\DbException
     */

    public function MenuDel(){
        $post  =$this->request->post();
        $id = isset($post['id']) ?intval($post['id']) :"";
        $menu =  Db::name("admin_menu")->where("id","=",$id)->find();
        if($menu==false){
            return error_show(1003,"菜单不信息不存在");
        }
        $menu['is_show']=0;
        $menu['status']=0;
        $menu['is_del']=1;
        $menu['updatetime']=date("Y-m-d H:i:s");
        $result =  Db::name("admin_menu")->save($menu);
        return $result ? app_show(0,"删除成功"): error_show(1003,"删除失败");
    }

    /**
     * @return \think\response\Json|void
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     */
    public function MenuActionDel(){
        $post  =$this->request->post();

        $id = isset($post['id']) ?intval($post['id']) :"";
        $menu =  Db::name("action")->where("id","=",$id)->find();
        if($menu==false){
            return error_show(1003,"菜单功能信息不存在");
        }

        $result =  Db::name("action")->delete($menu);
        return $result ? app_show(0,"删除成功"): error_show(1003,"删除失败");
    }
}
